# trompy

A collection of tools for plotting and data analysis from McCutcheon Lab based at UiT in Tromsø, Norway (hence *trom-py*). We study ingestive behavior and motivation in rodent neuroscience experiments but code may be useful in other settings.
 
Highlights include:
 - ~~GUI for analyzing lick patterns in rodent feeding and drinking experiments~~ [^1]
 - ~~GUI for analyzing fiber photometry data from rodent neuroscience experiments~~
 - Function for plotting bar plots with individual data points
 - Function for reading data files produced by Med Associates behavioral equipment
 - Functions for analyzing patterns of licking in rodent experiments
 - Functions for performing ROC (receiver-operator characteristic) analysis
 
 [^1]: GUIs are now available as separate packages: https://github.com/mccutcheonlab/Lick-Calc-GUI and https://github.com/mccutcheonlab/photogui
 
Code is maintained by James McCutcheon, Dept of Psychology, UiT The Arctic University of Norway.

### Installation
The simplest way to install is via the pip package manager. Briefly, from a terminal run

    pip install trompy
 
Dependencies will be automatically downloaded but are also listed in environment
 
### Previous versions

https://pypi.org/project/trompy/#history

### How to cite this project?

Please email jmc010@uit.no to get instructions on how to properly cite this project.

### Contributing

You are welcome to contribute to the code via pull requests.  Please have a
look at the [NLeSC
guide](https://nlesc.gitbooks.io/guide/content/software/software_overview.html)
for guidelines about software development.
